// Converts it into a client-side component to use the useSelectedLayoutSegments hook
"use client";

import { useState } from "react";
import { useSelectedLayoutSegments } from "next/navigation";
import Link from "next/link";
import NavItem from "./NavItem";
import HamburgerIcon from "./HamburgerIcon";
import DropdownIcon from "./DropdownIcon";

/**
 * @function Header is the function that generates the Header component which is used in the layout.tsx file so its displayed at the top of every page
 * @param data data fetched and passed down from the layout.tsx file
 * @returns A nav element with dynamic data based on the market the users is currently on
 */

const Header = ({ data }: any) => {
  // States to control functionality such as which dropdown that should be open
  const [visible, setVisible] = useState<boolean>(false);
  const [isOpen, setIsOpen] = useState<boolean>(false);
  const [active, setActive] = useState<string>("");

  // A built in hook from Next that returns a list of the sub-routes of the current pathname, eg. ['no', 'produkter']
  const fullPathName = useSelectedLayoutSegments();

  // Checks if the first element (which will always be the country code) contains 'no', to see which market the user is currently on
  const isOnNationalMarket = fullPathName[0].includes("no");

  // Set the correct data to be used in the dropdown links based on the market the user is currently on
  const dataBasedOnPathName = isOnNationalMarket ? data[0][0] : data[1][0];

  // The links for the header on the pages for the national market
  const nationalLinks = [
    {
      title: "Produkter",
      href: "en/products",
      shouldRedirect: true,
      dropdownLinks: dataBasedOnPathName["Produkter"],
    },
    {
      title: "Analyser",
      href: "no/analyser",
      shouldRedirect: false,
      dropdownLinks: dataBasedOnPathName["Analyser"],
    },
    {
      title: "Tjenester",
      href: "no/tjenester",
      shouldRedirect: false,
      dropdownLinks: dataBasedOnPathName["Tjenester"],
    },
    {
      title: "Om oss",
      href: "no/omOss",
      shouldRedirect: true,
      dropdownLinks: [],
    },
    {
      title: "Kontakt",
      href: "no/kontakt",
      shouldRedirect: true,
      dropdownLinks: [],
    },
    {
      title: "Change market",
      href: "en/",
      shouldRedirect: false,
      dropdownLinks: [
        { slug: "", title: "Change to the international market" },
      ],
    },
  ];

  // The links for the header on the pages for the international market
  const internationalLinks = [
    {
      title: "Products",
      href: "en/products",
      shouldRedirect: true,
      dropdownLinks: dataBasedOnPathName["Products"],
    },
    {
      title: "Services",
      href: "en/services",
      shouldRedirect: false,
      dropdownLinks: dataBasedOnPathName["Services"],
    },
    {
      title: "Applications",
      href: "en/applications",
      shouldRedirect: false,
      dropdownLinks: dataBasedOnPathName["Applications"],
    },
    {
      title: "About",
      href: "en/about",
      shouldRedirect: true,
      dropdownLinks: [],
    },
    {
      title: "Contact",
      href: "en/contact",
      shouldRedirect: true,
      dropdownLinks: [],
    },
    {
      title: "Endre marked",
      href: "no/",
      shouldRedirect: false,
      dropdownLinks: [{ slug: "", title: "Endre til det nasjonale markedet" }],
    },
  ];

  // Sets the correct links, including the dropdown links based on the market the user is on
  const links = isOnNationalMarket ? nationalLinks : internationalLinks;

  return (
    <nav className="w-screen z-50 lg:h-28 flex flex-col">
      <div className=" h-28 flex flex-row relative justify-between items-center lg:flex-row lg:justify-between  z-[90] text-white bg-header-footer  shadow-xl ">
        <div
          className={`${
            isOnNationalMarket ? "lg:w-2/5" : "lg:w-1/5"
          }  h-full w-3/4 pl-10 md:pl-10 flex flex-row justify-left items-center `}
        >
          <Link
            aria-label="Navigates to homepage"
            onClick={() => {
              isOpen ? setIsOpen(!isOpen) : null;
            }}
            href={isOnNationalMarket ? "/no" : "/en"}
          >
            {isOnNationalMarket ? (
              <div className="text-center flex flex-col justify-center items-center">
                <h1
                  role="heading"
                  aria-labelledby="NationalTitle"
                  className="text-4xl flex flex-row items-center justify-center "
                >
                  SEM
                  <p className="hidden lg:flex text-sm xl:text-xl ml-2">
                    - Scanning Electron Microscope
                  </p>
                </h1>
                <h2
                  role="heading"
                  aria-labelledby="NationalCompanyTitle"
                  className="text-sm md:text-sm self-start"
                >
                  Jarle Hjelen AS
                </h2>
              </div>
            ) : (
              <div className="text-center">
                <h1
                  role="heading"
                  aria-labelledby="InternationalTitle"
                  className="text-4xl"
                >
                  NORDIF®
                </h1>
                <h2
                  role="heading"
                  aria-labelledby="InternationalCompanyTitle"
                  className="text-sm"
                >
                  Jarle Hjelen AS
                </h2>
              </div>
            )}
          </Link>
        </div>
        <div
          className={`${
            isOnNationalMarket ? "lg:w-3/5" : "lg:w-4/5"
          }  w-3/4  h-full pr-10 lg:pr-0 `}
        >
          {/* The hamburger icon on the mobile view */}
          <div className="flex w-full h-full  items-center justify-end lg:hidden">
            <button
              aria-label="HamburgerIcon"
              onClick={() => {
                setIsOpen(!isOpen);
                setActive("");
              }}
              className="flex flex-col h-12 w-12 border-white border rounded justify-center items-center group"
            >
              <HamburgerIcon isOpen={isOpen} />
            </button>
          </div>
          {/* The links on the desktop view, in the same div as the hamburger icon, using hidden and lg:flex to correctly display them */}
          <div className="w-full h-full lg:flex justify-end items-end hidden ">
            <ul
              role="list"
              aria-labelledby="NavItemList"
              className="h-full hidden lg:flex flex-row lg:gap-2      z-50 lg:pr-6 "
            >
              {links.map((link, index) => {
                return <NavItem link={link} index={index} />;
              })}
            </ul>
          </div>
        </div>
      </div>
      {/* The dropdown on mobile view. With transition so that it goes outside the view on top when isOpen is false */}
      <div
        className={`left-0 absolute z-[85] bg-header-footer shadow-xl duration-500 ease-in ${
          isOpen ? "top-28 " : "top-[-100vh]"
        }`}
      >
        <ul
          role="list"
          aria-labelledby="DropdownNavList"
          className={`flex w-screen flex-col lg:hidden justify-center items-center border-t-2 gap-6 pt-5 max-h-screen  `}
        >
          {/* The links on mobile */}
          {links.map((link: any, index) => {
            return (
              <li
                key={`mobile_${link.title}`}
                className={`w-full flex justify-center items-center flex-col text-white text-2xl z-50  border-b border-gray-500 ${
                  active === link.title ? "pb-0" : " pb-5"
                }  
                `}
              >
                <div className="flex flex-row justify-center items-center ">
                  {/* Checks if the link should redirect and if so it returns a link to the correct href, or else it returns a regular p element */}
                  {link.shouldRedirect ? (
                    <Link
                      aria-label={`Navigates to ${link.title}`}
                      onClick={() => setIsOpen(!isOpen)}
                      href={`${link?.href}`}
                      className="text-xl pr-2 "
                    >
                      {link.title}
                    </Link>
                  ) : (
                    <p
                      aria-label={`Opens dropdown for ${link.title}`}
                      className="text-xl pr-2 cursor-pointer "
                      onClick={() => {
                        setActive(() =>
                          active === link.title ? "" : link.title
                        );
                      }}
                    >
                      {link.title}
                    </p>
                  )}
                  {/* If the link has dropdown links it will show the DropdownIcon symbol */}
                  {link?.dropdownLinks?.length > 0 ? (
                    <div
                      role="link"
                      aria-label={`Navigates to ${link.title}`}
                      className="cursor-pointer relative flex justify-center items-center  h-full"
                      onClick={() => {
                        setActive(() =>
                          active === link.title ? "" : link.title
                        );
                      }}
                    >
                      <DropdownIcon isOpen={link.title === active} />
                    </div>
                  ) : (
                    <></>
                  )}
                </div>
                {/* If the dropdown link on the mobile dropdown is pressed the correct dropdown will be shown */}
                {active === link.title ? (
                  <div className="w-screen  mt-5 flex justify-center items-center flex-row">
                    <div className=" w-[90%] transition-all duration-500 ease-in flex justify-center items-center flex-col  ">
                      {link.dropdownLinks?.map((dropdownLink: any) => {
                        return (
                          <Link
                            aria-label="Sublink"
                            key={`mobile_${dropdownLink.slug}`}
                            onClick={() => {
                              setVisible(!visible);
                              setIsOpen(!isOpen);
                            }}
                            href={`/${link?.href}/${dropdownLink.slug}`}
                            className={`text-sm py-5 my-1 bg-slate-700 w-screen h-full flex justify-center items-center text-center z-50 transition-all duration-500 ease-in ${
                              active === link.title
                                ? "scale-y-100"
                                : "scale-y-0"
                            }`}
                          >
                            {dropdownLink.title}
                          </Link>
                        );
                      })}
                    </div>
                  </div>
                ) : (
                  <></>
                )}
              </li>
            );
          })}
        </ul>
      </div>
    </nav>
  );
};

export default Header;
