// Converts the component to a client-component to be able to use hooks
"use client";

import Link from "next/link";
import { usePathname } from "next/navigation";
import { useState } from "react";
import { AiOutlineDown, AiOutlineUp } from "react-icons/ai";

interface props {
  link: {
    title: string;
    href: string;
    shouldRedirect: boolean;
    dropdownLinks: [];
  };
  index: number;
}

/**
 * @param props The parameters passed down from the Header component
 * @returns A component for a link in the navbar, including it's possible dropdowns on desktop view
 */
export default function NavItem(props: props) {
  // Uses the built in hook from Next to check which sub menu the user is on, to correctly set background color and cursor
  const pathname: string = usePathname();

  // State to show and hide the dropdown menu when the the arrow is pressed. Simply for navigation with keyboard.
  const [isVisible, setIsVisible] = useState(false);

  return (
    <li
      role="listitem"
      key={`${props.link.title}/${props.index}`}
      className={`group h-full  hover:bg-slate-800 relative ${
        pathname?.includes(`/${props.link?.href}`) ? "bg-slate-800" : ""
      }`}
    >
      <div className="h-full flex flex-row justify-center items-center cursor-pointer px-4 2xl:px-10">
        <Link
          onClick={() => setIsVisible(false)}
          aria-label={`Navigates to ${props.link.title}`}
          href={props.link.shouldRedirect ? `/${props.link?.href}` : "/#"}
          className="h-full flex  justify-center items-center hover:bg-slate-800  text-center no-underline"
        >
          <p className="text-xl lg:text-sm 2xl:text-lg py-5 lg:py-0">
            {props.link?.title}
          </p>
        </Link>
        {props.link?.dropdownLinks?.length > 0 ? (
          <button
            onClick={() => setIsVisible(!isVisible)}
            className="h-full"
            id={props.link.title}
            aria-label={props.link.title}
          >
            {isVisible ? (
              <AiOutlineUp className="ml-1" />
            ) : (
              <AiOutlineDown className="ml-1" />
            )}
          </button>
        ) : (
          <></>
        )}
      </div>

      <ul
        className={`${
          isVisible ? "" : "hidden"
        } w-56 group-hover:flex absolute flex-col transition-all ease-in-out z-[100] ${
          props.index > 3 ? "right-0" : ""
        } `}
      >
        {props.link.dropdownLinks?.map((dropdownLink: any, index) => {
          return (
            <li
              role="listitem"
              key={`${dropdownLink.slug}/${index}`}
              className={`w-full   hover:text-white border-t-2   self-center z-[100]  ${
                pathname?.includes(`/${props.link?.href}/${dropdownLink.slug}`)
                  ? "bg-slate-600 cursor-default"
                  : "bg-slate-800 hover:bg-slate-700"
              } `}
            >
              <Link
                onClick={() => setIsVisible(false)}
                aria-label={`Dropdown navigates to ${props.link.title}`}
                href={`/${props.link?.href}/${dropdownLink.slug}`}
                className={`h-full flex px-5 py-4 justify-center items-center  text-center no-underline ${
                  pathname?.includes(
                    `/${props.link?.href}/${dropdownLink.slug}`
                  )
                    ? "cursor-default"
                    : "cursor-pointer"
                }`}
              >
                <p className="text-sm 2xl:text-lg text-center ">
                  {dropdownLink?.title}
                </p>
              </Link>
            </li>
          );
        })}
      </ul>
    </li>
  );
}
