// Imports the global styles
import "../styles/globals.css";

import Header from "./components/Header";
import Footer from "./components/Footer";

import { ScrollToTop } from "./components/ToTopButton";
import { Metadata } from "next";
import { Inter } from "next/font/google";
import { Analytics } from "@vercel/analytics/react";
import {
  getInternationalHeaderItems,
  getNationalHeaderItems,
} from "queries/service";
import { navigationData } from "types/sanity";

// Set the custom font
const inter = Inter({
  subsets: ["latin"],
  variable: "--font-inter",
});

// Sets the fallback metadata if the metadata for the specific pages fails
export const metadata: Metadata = {
  title: "NORDIF®",
  description: "Website for NORDIF® - Jarle Hjelen AS",
};

// Exports a built in const that sets when the content of the page should revalidate, and if outdated refetched. In seconds so 3600 equals one hour
export const revalidate = 3600;

/**
 * @param children The component should accept a children prop that will be populated with a child layout (if it exists) or a child page during rendering
 * @returns A layout that is shared between multiple pages. On navigation, layouts preserve state, remain interactive, and do not re-render.
 */

export default async function RootLayout({
  children,
}: {
  children: React.ReactNode;
}) {
  // Fetches the data for the two different markets which is passed to the Header component
  const nationalHeaderItems: navigationData = await getNationalHeaderItems();
  const internationalHeaderItems: navigationData =
    await getInternationalHeaderItems();
  const data = [nationalHeaderItems, internationalHeaderItems];

  return (
    // Adds smooth scrolling, in addition to set the lang to norwegian
    <html className="scroll-smooth" lang="no">
      {/* Sets the imported custom font on the wole body */}
      <body className={`${inter.variable} font-Inter`}>
        {/* The header component that should be rendered on the top of each page, with the correct data */}
        <Header data={data} />
        {/* All of the children elements is rendered within a main element for semantics */}
        <main>{children}</main>
        {/* The button to navigate the user back to the top of the page, which should also be included on every page */}
        <ScrollToTop />
        {/* The footer component which also should be dislayed at the bottom of each page */}
        <Footer />
        {/* This components is a built in component from Vercel which allows for the analytics to be collected into the Vercel dashboard */}
        <Analytics />
      </body>
    </html>
  );
}
